@@ -1,40 +1,48 @@
 # system configuration generated and used by the sysconfig module
-build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
+build_time_vars = {'ABIFLAGS': 'm',
+ 'AC_APPLE_UNIVERSAL_BUILD': 0,
  'AIX_GENUINE_CPLUSPLUS': 0,
  'AR': 'ar',
  'ARFLAGS': 'rc',
- 'ATHEOS_THREADS': 0,
+ 'ASDLGEN': 'python ./Parser/asdl_c.py',
+ 'ASDLGEN_FILES': './Parser/asdl.py ./Parser/asdl_c.py',
+ 'AST_ASDL': './Parser/Python.asdl',
+ 'AST_C': 'Python/Python-ast.c',
+ 'AST_C_DIR': 'Python',
+ 'AST_H': 'Include/Python-ast.h',
+ 'AST_H_DIR': 'Include',
  'BASECFLAGS': '-fno-strict-aliasing -fno-common -dynamic',
+ 'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
- 'BEOS_THREADS': 0,
- 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/bin',
- 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7',
+ 'BINDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/bin',
+ 'BINLIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
  'BLDLIBRARY': '',
- 'BLDSHARED': '/opt/local/bin/clang-mp-3.4 -bundle -undefined dynamic_lookup -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -L/opt/local/lib/db48 ',
+ 'BLDSHARED': '/usr/bin/gcc-4.2 -bundle -undefined dynamic_lookup -L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'CC': '/opt/local/bin/clang-mp-3.4',
+ 'BUILD_GNU_TYPE': 'i386-apple-darwin10.8.0',
+ 'BYTESTR_DEPS': '\\',
+ 'CC': '/usr/bin/gcc-4.2',
  'CCSHARED': '',
- 'CFLAGS': '-fno-strict-aliasing -fno-common -dynamic -pipe -I/opt/local/libexec/openssl11/include -Os  -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
+ 'CFLAGS': '-fno-strict-aliasing -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os ',
  'CFLAGSFORSHARED': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--prefix=/opt/local' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--with-system-expat' '--with-system-ffi' 'CC=/opt/local/bin/clang-mp-3.4' 'CFLAGS=-pipe -I/opt/local/libexec/openssl11/include -Os ' 'LDFLAGS=-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -L/opt/local/lib/db48 ' 'CPPFLAGS=-I/opt/local/libexec/openssl11/include -isystem/opt/local/include -I/opt/local/include/db48' 'PKG_CONFIG_PATH=/opt/local/libexec/openssl11/lib/pkgconfig'",
- 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/include',
- 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/include/python2.7',
- 'COREPYTHONPATH': ':plat-darwin:plat-mac:plat-mac/lib-scriptpackages:lib-tk:lib-old',
- 'COVERAGE_INFO': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python27/python27/work/Python-2.7.18/coverage.info',
- 'COVERAGE_REPORT': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python27/python27/work/Python-2.7.18/lcov-report',
- 'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
- 'CPPFLAGS': '-I. -IInclude -I./Include -I/opt/local/libexec/openssl11/include -isystem/opt/local/include -I/opt/local/include/db48',
- 'CXX': '/opt/local/bin/clang++-mp-3.4',
- 'C_THREADS': 0,
- 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7 /opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib /opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7 /opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/lib-dynload',
- 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7',
+ 'CONFIGURE_CFLAGS': '-pipe -Os ',
+ 'CONFIGURE_CPPFLAGS': '-I/opt/local/include/openssl-1.0 -I/opt/local/include',
+ 'CONFIGURE_LDFLAGS': '-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
+ 'CONFIG_ARGS': "'--prefix=/opt/local' '--enable-framework=/opt/local/Library/Frameworks' '--enable-ipv6' '--enable-loadable-sqlite-extensions' '--with-computed-gotos' 'CC=/usr/bin/gcc-4.2' 'CFLAGS=-pipe -Os ' 'LDFLAGS=-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ' 'CPPFLAGS=-I/opt/local/include/openssl-1.0 -I/opt/local/include'",
+ 'CONFINCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include',
+ 'CONFINCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m',
+ 'COREPYTHONPATH': ':plat-darwin',
+ 'CPPFLAGS': '-I. -IInclude -I./Include -I/opt/local/include/openssl-1.0 -I/opt/local/include',
+ 'CXX': '/usr/bin/g++-4.2',
+ 'DESTDIRS': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3 /opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib /opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3 /opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/lib-dynload',
+ 'DESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
  'DESTPATH': '',
- 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/lib-dynload',
+ 'DESTSHARED': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/lib-dynload',
  'DIRMODE': 755,
- 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Demo Ext-dummy',
- 'DISTDIRS': 'Include Lib Misc Demo Ext-dummy',
+ 'DIST': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in Include Lib Misc Ext-dummy',
+ 'DISTDIRS': 'Include Lib Misc Ext-dummy',
  'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
  'DLLLIBRARY': '',
@@ -43,22 +51,22 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
- 'ENSUREPIP': 'no',
  'EXE': '',
  'EXEMODE': 755,
- 'EXTRAMACHDEPPATH': ':plat-mac:plat-mac/lib-scriptpackages',
- 'EXTRAPLATDIR': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
+ 'EXTRAMACHDEPPATH': '',
+ 'EXTRAPLATDIR': '@EXTRAPLATDIR@',
  'EXTRATESTOPTS': '',
  'EXTRA_CFLAGS': '',
+ 'EXT_SUFFIX': '.so',
  'FILEMODE': 644,
  'FLOCK_NEEDS_LIBBSD': 0,
  'GETPGRP_HAVE_ARG': 0,
  'GETTIMEOFDAY_NO_TZ': 0,
- 'GITBRANCH': '',
- 'GITTAG': '',
- 'GITVERSION': '',
- 'GLHACK': '-Dclear=__GLclear',
  'GNULD': 'no',
+ 'GRAMMAR_C': 'Python/graminit.c',
+ 'GRAMMAR_H': 'Include/graminit.h',
+ 'GRAMMAR_INPUT': './Grammar/Grammar',
+ 'HAVE_ACCEPT4': 0,
  'HAVE_ACOSH': 1,
  'HAVE_ADDRINFO': 1,
  'HAVE_ALARM': 1,
@@ -71,6 +79,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
+ 'HAVE_BROKEN_MBSTOWCS': 0,
  'HAVE_BROKEN_NICE': 0,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
@@ -83,25 +92,18 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_CHOWN': 1,
  'HAVE_CHROOT': 1,
  'HAVE_CLOCK': 1,
+ 'HAVE_CLOCK_GETRES': 0,
+ 'HAVE_CLOCK_GETTIME': 0,
  'HAVE_COMPUTED_GOTOS': 1,
  'HAVE_CONFSTR': 1,
  'HAVE_CONIO_H': 0,
  'HAVE_COPYSIGN': 1,
- 'HAVE_CRYPT_H': 0,
  'HAVE_CTERMID': 1,
  'HAVE_CTERMID_R': 1,
- 'HAVE_CURSES_FILTER': 1,
  'HAVE_CURSES_H': 1,
- 'HAVE_CURSES_HAS_KEY': 1,
- 'HAVE_CURSES_IMMEDOK': 1,
- 'HAVE_CURSES_IS_PAD': 1,
  'HAVE_CURSES_IS_TERM_RESIZED': 1,
  'HAVE_CURSES_RESIZETERM': 1,
  'HAVE_CURSES_RESIZE_TERM': 1,
- 'HAVE_CURSES_SYNCOK': 1,
- 'HAVE_CURSES_TYPEAHEAD': 1,
- 'HAVE_CURSES_USE_ENV': 1,
- 'HAVE_CURSES_WCHGAT': 1,
  'HAVE_DECL_ISFINITE': 1,
  'HAVE_DECL_ISINF': 1,
  'HAVE_DECL_ISNAN': 1,
@@ -111,22 +113,28 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_DEV_PTMX': 1,
  'HAVE_DIRECT_H': 0,
  'HAVE_DIRENT_H': 1,
+ 'HAVE_DIRFD': 1,
  'HAVE_DLFCN_H': 1,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
- 'HAVE_DYLD_SHARED_CACHE_CONTAINS_PATH': 0,
  'HAVE_DYNAMIC_LOADING': 1,
  'HAVE_EPOLL': 0,
+ 'HAVE_EPOLL_CREATE1': 0,
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
  'HAVE_EXECV': 1,
  'HAVE_EXPM1': 1,
+ 'HAVE_FACCESSAT': 0,
  'HAVE_FCHDIR': 1,
  'HAVE_FCHMOD': 1,
+ 'HAVE_FCHMODAT': 0,
  'HAVE_FCHOWN': 1,
+ 'HAVE_FCHOWNAT': 0,
  'HAVE_FCNTL_H': 1,
  'HAVE_FDATASYNC': 0,
+ 'HAVE_FDOPENDIR': 0,
+ 'HAVE_FEXECVE': 0,
  'HAVE_FINITE': 1,
  'HAVE_FLOCK': 1,
  'HAVE_FORK': 1,
@@ -134,19 +142,25 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_FPATHCONF': 1,
  'HAVE_FSEEK64': 0,
  'HAVE_FSEEKO': 1,
+ 'HAVE_FSTATAT': 0,
  'HAVE_FSTATVFS': 1,
  'HAVE_FSYNC': 1,
  'HAVE_FTELL64': 0,
  'HAVE_FTELLO': 1,
  'HAVE_FTIME': 1,
  'HAVE_FTRUNCATE': 1,
+ 'HAVE_FUTIMENS': 0,
+ 'HAVE_FUTIMES': 1,
+ 'HAVE_FUTIMESAT': 0,
  'HAVE_GAI_STRERROR': 1,
  'HAVE_GAMMA': 1,
+ 'HAVE_GCC_ASM_FOR_X64': 0,
  'HAVE_GCC_ASM_FOR_X87': 1,
+ 'HAVE_GCC_UINT128_T': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETCWD': 1,
  'HAVE_GETC_UNLOCKED': 1,
- 'HAVE_GETENTROPY': 0,
+ 'HAVE_GETGROUPLIST': 1,
  'HAVE_GETGROUPS': 1,
  'HAVE_GETHOSTBYNAME': 1,
  'HAVE_GETHOSTBYNAME_R': 0,
@@ -171,10 +185,12 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETSPNAM': 0,
  'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
+ 'HAVE_GLIBC_MEMMOVE_BUG': 0,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
  'HAVE_HYPOT': 1,
  'HAVE_IEEEFP_H': 0,
+ 'HAVE_IF_NAMEINDEX': 1,
  'HAVE_INET_ATON': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
@@ -182,6 +198,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_INT64_T': 1,
  'HAVE_INTTYPES_H': 1,
  'HAVE_IO_H': 0,
+ 'HAVE_IPA_PURE_CONST_BUG': 0,
  'HAVE_KILL': 1,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 1,
@@ -197,67 +214,97 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LIBINTL_H': 1,
  'HAVE_LIBREADLINE': 1,
  'HAVE_LIBRESOLV': 0,
+ 'HAVE_LIBSENDFILE': 0,
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
+ 'HAVE_LINKAT': 0,
+ 'HAVE_LINUX_CAN_H': 0,
+ 'HAVE_LINUX_CAN_RAW_H': 0,
  'HAVE_LINUX_NETLINK_H': 0,
  'HAVE_LINUX_TIPC_H': 0,
+ 'HAVE_LOCKF': 1,
  'HAVE_LOG1P': 1,
+ 'HAVE_LOG2': 1,
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LONG_LONG': 1,
  'HAVE_LSTAT': 1,
+ 'HAVE_LUTIMES': 1,
  'HAVE_MAKEDEV': 1,
+ 'HAVE_MBRTOWC': 1,
  'HAVE_MEMMOVE': 1,
  'HAVE_MEMORY_H': 1,
+ 'HAVE_MEMRCHR': 0,
+ 'HAVE_MKDIRAT': 0,
  'HAVE_MKFIFO': 1,
+ 'HAVE_MKFIFOAT': 0,
  'HAVE_MKNOD': 1,
+ 'HAVE_MKNODAT': 0,
  'HAVE_MKTIME': 1,
  'HAVE_MMAP': 1,
  'HAVE_MREMAP': 0,
  'HAVE_NCURSES_H': 1,
  'HAVE_NDIR_H': 0,
  'HAVE_NETPACKET_PACKET_H': 0,
+ 'HAVE_NET_IF_H': 1,
  'HAVE_NICE': 1,
+ 'HAVE_OPENAT': 0,
  'HAVE_OPENPTY': 1,
  'HAVE_OSX105_SDK': 1,
  'HAVE_PATHCONF': 1,
  'HAVE_PAUSE': 1,
+ 'HAVE_PIPE2': 0,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 0,
  'HAVE_POLL_H': 0,
+ 'HAVE_POSIX_FADVISE': 0,
+ 'HAVE_POSIX_FALLOCATE': 0,
+ 'HAVE_PREAD': 1,
  'HAVE_PROCESS_H': 0,
  'HAVE_PROTOTYPES': 1,
- 'HAVE_PTH': 0,
  'HAVE_PTHREAD_ATFORK': 1,
  'HAVE_PTHREAD_DESTRUCTOR': 0,
  'HAVE_PTHREAD_H': 1,
  'HAVE_PTHREAD_INIT': 0,
+ 'HAVE_PTHREAD_KILL': 1,
  'HAVE_PTHREAD_SIGMASK': 1,
  'HAVE_PTY_H': 0,
  'HAVE_PUTENV': 1,
+ 'HAVE_PWRITE': 1,
  'HAVE_READLINK': 1,
+ 'HAVE_READLINKAT': 0,
+ 'HAVE_READV': 1,
  'HAVE_REALPATH': 1,
+ 'HAVE_RENAMEAT': 0,
  'HAVE_RL_CALLBACK': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
- 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 1,
+ 'HAVE_RL_COMPLETION_SUPPRESS_APPEND': 0,
  'HAVE_RL_PRE_INPUT_HOOK': 1,
- 'HAVE_RL_RESIZE_TERMINAL': 1,
  'HAVE_ROUND': 1,
+ 'HAVE_SCHED_GET_PRIORITY_MAX': 1,
+ 'HAVE_SCHED_H': 1,
+ 'HAVE_SCHED_RR_GET_INTERVAL': 0,
+ 'HAVE_SCHED_SETAFFINITY': 0,
+ 'HAVE_SCHED_SETPARAM': 0,
+ 'HAVE_SCHED_SETSCHEDULER': 0,
  'HAVE_SELECT': 1,
  'HAVE_SEM_GETVALUE': 1,
  'HAVE_SEM_OPEN': 1,
  'HAVE_SEM_TIMEDWAIT': 0,
  'HAVE_SEM_UNLINK': 1,
+ 'HAVE_SENDFILE': 1,
  'HAVE_SETEGID': 1,
  'HAVE_SETEUID': 1,
  'HAVE_SETGID': 1,
  'HAVE_SETGROUPS': 1,
+ 'HAVE_SETHOSTNAME': 1,
  'HAVE_SETITIMER': 1,
  'HAVE_SETLOCALE': 1,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
+ 'HAVE_SETPRIORITY': 1,
  'HAVE_SETREGID': 1,
  'HAVE_SETRESGID': 0,
  'HAVE_SETRESUID': 0,
@@ -267,9 +314,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SETVBUF': 1,
  'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
+ 'HAVE_SIGALTSTACK': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
+ 'HAVE_SIGPENDING': 1,
  'HAVE_SIGRELSE': 1,
+ 'HAVE_SIGTIMEDWAIT': 0,
+ 'HAVE_SIGWAIT': 1,
+ 'HAVE_SIGWAITINFO': 0,
  'HAVE_SNPRINTF': 1,
  'HAVE_SOCKADDR_SA_LEN': 1,
  'HAVE_SOCKADDR_STORAGE': 1,
@@ -286,6 +338,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRFTIME': 1,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
+ 'HAVE_STRLCPY': 1,
  'HAVE_STROPTS_H': 0,
  'HAVE_STRUCT_STAT_ST_BIRTHTIME': 1,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
@@ -294,15 +347,21 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRUCT_STAT_ST_GEN': 1,
  'HAVE_STRUCT_STAT_ST_RDEV': 1,
  'HAVE_STRUCT_TM_TM_ZONE': 1,
+ 'HAVE_ST_BLOCKS': 1,
  'HAVE_SYMLINK': 1,
+ 'HAVE_SYMLINKAT': 0,
+ 'HAVE_SYNC': 1,
  'HAVE_SYSCONF': 1,
  'HAVE_SYSEXITS_H': 1,
  'HAVE_SYS_AUDIOIO_H': 0,
  'HAVE_SYS_BSDTTY_H': 0,
+ 'HAVE_SYS_DEVPOLL_H': 0,
  'HAVE_SYS_DIR_H': 0,
  'HAVE_SYS_EPOLL_H': 0,
  'HAVE_SYS_EVENT_H': 1,
  'HAVE_SYS_FILE_H': 1,
+ 'HAVE_SYS_IOCTL_H': 1,
+ 'HAVE_SYS_KERN_CONTROL_H': 1,
  'HAVE_SYS_LOADAVG_H': 0,
  'HAVE_SYS_LOCK_H': 1,
  'HAVE_SYS_MKDEV_H': 0,
@@ -310,27 +369,29 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_NDIR_H': 0,
  'HAVE_SYS_PARAM_H': 1,
  'HAVE_SYS_POLL_H': 1,
- 'HAVE_SYS_RANDOM_H': 1,
  'HAVE_SYS_RESOURCE_H': 1,
  'HAVE_SYS_SELECT_H': 1,
+ 'HAVE_SYS_SENDFILE_H': 0,
  'HAVE_SYS_SOCKET_H': 1,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
- 'HAVE_SYS_SYSMACROS_H': 0,
+ 'HAVE_SYS_SYSCALL_H': 1,
+ 'HAVE_SYS_SYS_DOMAIN_H': 1,
  'HAVE_SYS_TERMIO_H': 0,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
  'HAVE_SYS_TYPES_H': 1,
+ 'HAVE_SYS_UIO_H': 1,
  'HAVE_SYS_UN_H': 1,
  'HAVE_SYS_UTSNAME_H': 1,
  'HAVE_SYS_WAIT_H': 1,
+ 'HAVE_SYS_XATTR_H': 1,
  'HAVE_TCGETPGRP': 1,
  'HAVE_TCSETPGRP': 1,
  'HAVE_TEMPNAM': 1,
  'HAVE_TERMIOS_H': 1,
  'HAVE_TERM_H': 1,
  'HAVE_TGAMMA': 1,
- 'HAVE_THREAD_H': 0,
  'HAVE_TIMEGM': 1,
  'HAVE_TIMES': 1,
  'HAVE_TMPFILE': 1,
@@ -345,78 +406,88 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_UINTPTR_T': 1,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
+ 'HAVE_UNLINKAT': 0,
  'HAVE_UNSETENV': 1,
  'HAVE_USABLE_WCHAR_T': 0,
  'HAVE_UTIL_H': 1,
+ 'HAVE_UTIMENSAT': 0,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
  'HAVE_WAIT3': 1,
  'HAVE_WAIT4': 1,
+ 'HAVE_WAITID': 1,
  'HAVE_WAITPID': 1,
  'HAVE_WCHAR_H': 1,
  'HAVE_WCSCOLL': 1,
+ 'HAVE_WCSFTIME': 1,
+ 'HAVE_WCSXFRM': 1,
  'HAVE_WORKING_TZSET': 1,
+ 'HAVE_WRITEV': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
+ 'HGBRANCH': '',
+ 'HGTAG': '',
+ 'HGVERSION': '',
  'HOST_GNU_TYPE': 'i386-apple-darwin10.8.0',
- 'HURD_C_THREADS': 0,
- 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/include /opt/local/Library/Frameworks/Python.framework/Versions/2.7/include /opt/local/Library/Frameworks/Python.framework/Versions/2.7/include/python2.7 /opt/local/Library/Frameworks/Python.framework/Versions/2.7/include/python2.7',
- 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/include',
- 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/include/python2.7',
+ 'INCLDIRSTOMAKE': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include /opt/local/Library/Frameworks/Python.framework/Versions/3.3/include /opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m /opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m',
+ 'INCLUDEDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include',
+ 'INCLUDEPY': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/include/python3.3m',
  'INSTALL': '/usr/bin/install -c',
  'INSTALL_DATA': '/usr/bin/install -c -m 644',
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'Python.framework/Versions/2.7/Python',
- 'LDCXXSHARED': '/opt/local/bin/clang++-mp-3.4 -bundle -undefined dynamic_lookup',
- 'LDFLAGS': '-L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -L/opt/local/lib/db48 ',
+ 'INSTSONAME': 'Python.framework/Versions/3.3/Python',
+ 'IO_H': 'Modules/_io/_iomodule.h',
+ 'IO_OBJS': '\\',
+ 'LDCXXSHARED': '/usr/bin/g++-4.2 -bundle -undefined dynamic_lookup',
+ 'LDFLAGS': '-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'LDLAST': '',
- 'LDLIBRARY': 'Python.framework/Versions/2.7/Python',
+ 'LDLIBRARY': 'Python.framework/Versions/3.3/Python',
  'LDLIBRARYDIR': '',
- 'LDSHARED': '/opt/local/bin/clang-mp-3.4 -bundle -undefined dynamic_lookup -L/opt/local/libexec/openssl11/lib -L/opt/local/lib -Wl,-headerpad_max_install_names -L/opt/local/lib/db48 ',
+ 'LDSHARED': '/usr/bin/gcc-4.2 -bundle -undefined dynamic_lookup -L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
+ 'LDVERSION': '3.3m',
  'LIBC': '',
- 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7',
- 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib',
- 'LIBFFI_INCLUDEDIR': '/opt/local/include',
+ 'LIBDEST': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
+ 'LIBDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib',
+ 'LIBFFI_INCLUDEDIR': '',
  'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
- 'LIBP': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7',
- 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/pkgconfig',
- 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/config',
- 'LIBRARY': 'libpython2.7.a',
+ 'LIBPC': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/pkgconfig',
+ 'LIBPL': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3/config-3.3m',
+ 'LIBRARY': 'libpython3.3m.a',
  'LIBRARY_OBJS': '\\',
- 'LIBS': '-lintl -ldl  -framework CoreFoundation',
- 'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
- 'LINKCC': '/opt/local/bin/clang-mp-3.4',
- 'LINKFORSHARED': '-L/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7/config -lpython2.7 -ldl -framework CoreFoundation',
- 'LLVM_PROF_ERR': 'yes',
- 'LLVM_PROF_FILE': 'LLVM_PROFILE_FILE="code-%p.profclangr"',
- 'LLVM_PROF_MERGER': "'' merge -output=code.profclangd *.profclangr",
+ 'LIBRARY_OBJS_OMIT_FROZEN': '\\',
+ 'LIBS': ' -ldl  -framework CoreFoundation',
+ 'LIBSUBDIRS': 'tkinter tkinter/test tkinter/test/test_tkinter \\',
+ 'LINKCC': '/usr/bin/gcc-4.2',
+ 'LINKFORSHARED': '-framework CoreFoundation Python.framework/Versions/3.3/Python',
  'LN': 'ln',
  'LOCALMODLIBS': '',
+ 'LOG1P_DROPS_ZERO_SIGN': 0,
  'MACHDEP': 'darwin',
  'MACHDEPPATH': ':plat-darwin',
- 'MACHDEPS': 'plat-darwin plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
- 'MACHDEP_OBJS': 'Python/mactoolboxglue.o',
- 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib/python2.7',
- 'MACH_C_THREADS': 0,
+ 'MACHDEPS': 'plat-darwin @EXTRAPLATDIR@',
+ 'MACHDEP_OBJS': '',
+ 'MACHDESTLIB': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib/python3.3',
  'MACOSX_DEPLOYMENT_TARGET': '10.6',
- 'MAINCC': '/opt/local/bin/clang-mp-3.4',
+ 'MAINCC': '/usr/bin/gcc-4.2',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
- 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/share/man',
- 'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
+ 'MANDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/share/man',
  'MKDIR_P': './install-sh -c -d',
  'MODLIBS': '',
- 'MODOBJS': 'Modules/threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/zipimport.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
+ 'MODOBJS': 'Modules/_threadmodule.o  Modules/signalmodule.o  Modules/posixmodule.o  Modules/errnomodule.o  Modules/pwdmodule.o  Modules/_sre.o  Modules/_codecsmodule.o  Modules/_weakref.o  Modules/_functoolsmodule.o  Modules/operator.o  Modules/_collectionsmodule.o  Modules/itertoolsmodule.o  Modules/_localemodule.o  Modules/_iomodule.o Modules/iobase.o Modules/fileio.o Modules/bytesio.o Modules/bufferedio.o Modules/textio.o Modules/stringio.o  Modules/zipimport.o  Modules/faulthandler.o  Modules/symtablemodule.o  Modules/xxsubtype.o',
  'MODULE_OBJS': '\\',
  'MULTIARCH': '',
  'MVWDELCH_IS_EXPRESSION': 1,
+ 'NO_AS_NEEDED': '',
  'OBJECT_OBJS': '\\',
- 'OLDPATH': ':lib-old',
+ 'OPCODETARGETGEN': '\\',
+ 'OPCODETARGETGEN_FILES': '\\',
+ 'OPCODETARGETS_H': '\\',
  'OPT': '-DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
@@ -426,53 +497,50 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PACKAGE_URL': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
- 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/tokenizer.o',
+ 'PARSER_OBJS': '\\ Parser/myreadline.o Parser/parsetok.o Parser/tokenizer.o',
  'PGEN': 'Parser/pgen',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
- 'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
- 'PGO_PROF_USE_FLAG': '-fprofile-instr-use=code.profclangd',
  'PGSRCS': '\\',
  'PLATDIR': 'plat-darwin',
- 'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
- 'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb test_multiprocessing test_subprocess',
+ 'PROFILE_TASK': './Tools/pybench/pybench.py -n 2 --with-gc --with-syscheck',
  'PSRCS': '\\',
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
+ 'PY3LIBRARY': '',
  'PYLONG_BITS_IN_DIGIT': 0,
  'PYTHON': 'python',
  'PYTHONFRAMEWORK': 'Python',
  'PYTHONFRAMEWORKDIR': 'Python.framework',
  'PYTHONFRAMEWORKINSTALLDIR': '/opt/local/Library/Frameworks/Python.framework',
  'PYTHONFRAMEWORKPREFIX': '/opt/local/Library/Frameworks',
- 'PYTHONPATH': ':plat-darwin:plat-mac:plat-mac/lib-scriptpackages:lib-tk:lib-old',
+ 'PYTHONPATH': ':plat-darwin',
  'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -fno-common -dynamic -pipe -I/opt/local/libexec/openssl11/include -Os  -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -I. -IInclude -I./Include -I/opt/local/libexec/openssl11/include -isystem/opt/local/include -I/opt/local/include/db48  -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os ',
+ 'PY_CORE_CFLAGS': '-fno-strict-aliasing -fno-common -dynamic -DNDEBUG -g -fwrapv -O3 -Wall -Wstrict-prototypes -pipe -Os  -I. -IInclude -I./Include -I/opt/local/include/openssl-1.0 -I/opt/local/include  -DPy_BUILD_CORE',
+ 'PY_CPPFLAGS': '-I. -IInclude -I./Include -I/opt/local/include/openssl-1.0 -I/opt/local/include',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_UNICODE_TYPE': 'unsigned short',
+ 'PY_LDFLAGS': '-L/opt/local/lib/openssl-1.0 -L/opt/local/lib -Wl,-headerpad_max_install_names ',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 0,
- 'Py_UNICODE_SIZE': 2,
- 'Py_USING_UNICODE': 1,
- 'QUICKTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\',
+ 'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
+ 'READELF': ':',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python27/python27/work/Python-2.7.18',
- 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/lib',
+ 'RUNSHARED': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7',
+ 'SCRIPTDIR': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lintl -ldl  -framework CoreFoundation',
- 'SHLIB_EXT': '".so"',
+ 'SHLIBS': ' -ldl  -framework CoreFoundation',
+ 'SHLIB_SUFFIX': '.so',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
@@ -494,35 +562,35 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SO': '.so',
- 'SRCDIRS': 'Parser Objects Python Modules Modules/_io',
+ 'SOABI': 'cpython-33m',
+ 'SRCDIRS': 'Parser Grammar Objects Python Modules Mac',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
- 'STRINGLIB_HEADERS': '\\',
  'SUBDIRS': '',
- 'SUBDIRSTOO': 'Include Lib Misc Demo',
+ 'SUBDIRSTOO': 'Include Lib Misc',
  'SYSLIBS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '',
  'TCLTK_LIBS': '',
- 'TESTOPTS': '-l',
+ 'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python27/python27/work/Python-2.7.18 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7 ./python',
  'TESTPYTHONOPTS': '',
+ 'TESTRUNNER': 'DYLD_FRAMEWORK_PATH=/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7 ./python ./Tools/scripts/run_tests.py',
+ 'TESTTIMEOUT': 3600,
  'THREADOBJ': 'Python/thread.o',
+ 'TIMEMODULE_LIB': 0,
  'TIME_WITH_SYS_TIME': 1,
- 'TKPATH': ':lib-tk',
  'TM_IN_SYS_TIME': 0,
- 'UNICODE_OBJS': 'Objects/unicodeobject.o Objects/unicodectype.o',
+ 'UNICODE_DEPS': '\\ \\',
  'UNIVERSALSDK': '',
- 'USE_COMPUTED_GOTOS': 0,
- 'USE_TOOLBOX_OBJECT_GLUE': 1,
+ 'USE_COMPUTED_GOTOS': 1,
+ 'USE_INLINE': 1,
  'VA_LIST_IS_ARRAY': 0,
- 'VERSION': '2.7',
+ 'VERSION': '3.3',
  'WANT_SIGFPE_HANDLER': 0,
- 'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DYLD': 1,
@@ -534,11 +602,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python27/python27/work/Python-2.7.18',
- 'abs_srcdir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python27/python27/work/Python-2.7.18',
- 'build': 'i386-apple-darwin10.8.0',
- 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7/share',
- 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7',
- 'host': 'i386-apple-darwin10.8.0',
- 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/2.7',
+ 'abs_builddir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7',
+ 'abs_srcdir': '/opt/local/var/macports/build/_opt_bblocal_var_buildworker_ports_build_ports_lang_python33/python33/work/Python-3.3.7',
+ 'datarootdir': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3/share',
+ 'exec_prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3',
+ 'prefix': '/opt/local/Library/Frameworks/Python.framework/Versions/3.3',
  'srcdir': '.'}
